import setuptools

setuptools.setup(
    name='projectmanagement',
    version='0.0.1',
    author='Filippo Maria Ottaviani',
    author_email='filippomariaottaviani@gmail.com',
    description='Project Management',
    packages=['projectmanagement']
)
